aboutsummaryrefslogtreecommitdiff
path: root/llvm/lib/Transforms/IPO/GlobalSplit.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'llvm/lib/Transforms/IPO/GlobalSplit.cpp')
-rw-r--r--llvm/lib/Transforms/IPO/GlobalSplit.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/llvm/lib/Transforms/IPO/GlobalSplit.cpp b/llvm/lib/Transforms/IPO/GlobalSplit.cpp
index e7d698c42fcf..7d9e6135b2eb 100644
--- a/llvm/lib/Transforms/IPO/GlobalSplit.cpp
+++ b/llvm/lib/Transforms/IPO/GlobalSplit.cpp
@@ -134,9 +134,9 @@ static bool splitGlobal(GlobalVariable &GV) {
}
// Finally, remove the original global. Any remaining uses refer to invalid
// elements of the global, so replace with undef.
if (!GV.use_empty())
- GV.replaceAllUsesWith(UndefValue::get(GV.getType()));
+ GV.replaceAllUsesWith(PoisonValue::get(GV.getType()));
GV.eraseFromParent();
return true;
}
@@ -134,9 +134,9 @@ static bool splitGlobal(GlobalVariable &GV) {
}
// Finally, remove the original global. Any remaining uses refer to invalid
- // elements of the global, so replace with undef.
+ // elements of the global, so replace with poison.
if (!GV.use_empty())